/*
This file creates an extract from the ACS at the household level that contains the covariates used as predictors in the conditional density of food stamp receipt and amounts. The local macros at the beginning can be used to change the names and path of the input and output files as well as the year range. You need a file with the poverty lines that should have been included with this program. The code works for 2008-2010 and may work for later years if the variable names and definitions do not change. It keeps the entire sample including group quarters and households in Puerto Rico (even though you'll most likely want to drop them). If you have any questions or suggestions, please send me an email (mittag@uchicago.edu).
*/


***setup
*first year of data to create
local f_year 2008
*last year of data to create
local l_year 2010

*name (and path) of ACS population file
local popfile data/acs\`year'_population_us.dta

*name (and path) of ACS household file
local hhfile data/acs\`year'_housing_us.dta

*name (and path) of file with poverty lines
local povfile data/povlines.dta

*name of output file to be saved
local outfile data/acs\`year'_cov.dta

***get ACS extracts at household level
foreach year of numlist `f_year'/`l_year' {
	if `year'==2010 local p "p"
	*load relevant variables from individual files
	use serialno agep rel`p' dis intp sex cit rac1p hisp schl esr eng using `popfile', clear
	
	*create variables for which all hh members are needed
	bysort serialno: egen disab_pr=min(dis)
	recode disab_pr (2=0)
 
	*dummy if anyone in hh had capital income
	gen tmp=(intp!=0 & intp!=1 & intp!=.)
	bysort serialno: egen cap_inc=max(tmp)
	drop tmp
 	 	
	*count children
	gen tmp=(agep<18)
	bysort serialno: egen nc=total(tmp)
	drop tmp

	*employment variables
	gen employed=(esr!=3 & esr!=6)
	bysort serialno: egen n_emp=total(employed)
	gen any_emp=(n_emp>0) 
	gen unempl=(esr==3)
	gen nilf=(esr==6)
	
	*keep only hh heads
	keep if rel`p'==0
	
	*HH head gender
	gen female=(sex==2)
	
	*head not a citizen
	gen non_cit=(cit==5)
 	
	*HH head white dummy
	gen rce_wht=(rac1p==1)
 	
	*head hispanic
	recode hisp (1=0) (2/24=1)
 	
	*HH head education
	gen educ_lths=(schl<=15)
	gen educ_hs=(schl==16 | schl==17)
	gen educ_soco=(schl>17 & schl<21)
	gen educ_cmor=(schl>=21 & schl!=.)
	
	*age dummies
	gen age18_29=(agep>=18 & agep<=29)
	gen age30_39=(agep>=30 & agep<=39)
	gen age40_49=(agep>=40 & agep<=49)
	gen age50_59=(agep>=50 & agep<=59)
	gen age60_69=(agep>=60 & agep<=69)
	gen age_ge70=(agep>=70)
 	
	*disability
	gen disab=(dis==1)
	gen disnowrk=(disab==1 & employed==0)
 	
	*bad or no english
	gen badeng=(eng==3)
	gen noeng=(eng==4)
 
	*merge with household file
	merge 1:1 serialno using `hhfile', keepusing(serialno fs ffsp r60 hincp nrc np noc wgtp hht lngi year)
	drop _merge

	*food stamp receipt and imputation status
	recode fs (2=0)
	ren ffsp ffs
	
	*dummy whether elderly or disabled person present
	gen eld_dis=(r60>0 | disab_pr==1)
 	
	*single person hh
	gen single_hh=(np==1)
 	 	 
	*household type
	gen nm0kid=(hht!=1 & noc==0)
	gen nmwkid=(hht!=1 & noc>0)
	gen mar0kid=(hht==1 & noc==0)
	gen marwkid=(hht==1 & noc>0)

	*no english speaker in hh
	gen noeng_hh=(lngi==2)
 	
	*get poverty line for hh
	gen hhpovtyp=1 if np==1 & agep<60
	replace hhpovtyp=2 if np==1 & agep>=60
	replace hhpovtyp=3 if np==2 & agep<60 & nrc==0
	replace hhpovtyp=4 if np==2 & agep<60 & nrc==1
	replace hhpovtyp=5 if np==2 & agep>=60 & nrc==0
	replace hhpovtyp=6 if np==2 & agep>=60 & nrc==1
	replace hhpovtyp=7 if np==3 & nrc==0
	replace hhpovtyp=8 if np==3 & nrc==1
	replace hhpovtyp=9 if np==3 & nrc==2
	replace hhpovtyp=10 if np==4 & nrc==0
	replace hhpovtyp=11 if np==4 & nrc==1
	replace hhpovtyp=12 if np==4 & nrc==2
	replace hhpovtyp=13 if np==4 & nrc==3
	replace hhpovtyp=14 if np==5 & nrc==0
	replace hhpovtyp=15 if np==5 & nrc==1
	replace hhpovtyp=16 if np==5 & nrc==2
	replace hhpovtyp=17 if np==5 & nrc==3
	replace hhpovtyp=18 if np==5 & nrc==4
	replace hhpovtyp=19 if np==6 & nrc==0
	replace hhpovtyp=20 if np==6 & nrc==1
	replace hhpovtyp=21 if np==6 & nrc==2
	replace hhpovtyp=22 if np==6 & nrc==3
	replace hhpovtyp=23 if np==6 & nrc==4
	replace hhpovtyp=24 if np==6 & nrc==5
	replace hhpovtyp=25 if np==7 & nrc==0
	replace hhpovtyp=26 if np==7 & nrc==1
	replace hhpovtyp=27 if np==7 & nrc==2
	replace hhpovtyp=28 if np==7 & nrc==3
	replace hhpovtyp=29 if np==7 & nrc==4
	replace hhpovtyp=30 if np==7 & nrc==5
	replace hhpovtyp=31 if np==7 & nrc==6
	replace hhpovtyp=32 if np==8 & nrc==0
	replace hhpovtyp=33 if np==8 & nrc==1
	replace hhpovtyp=34 if np==8 & nrc==2
	replace hhpovtyp=35 if np==8 & nrc==3
	replace hhpovtyp=36 if np==8 & nrc==4
	replace hhpovtyp=37 if np==8 & nrc==5
	replace hhpovtyp=38 if np==8 & nrc==6
	replace hhpovtyp=39 if np==8 & nrc==7
	replace hhpovtyp=40 if np>=9 & nrc==0
	replace hhpovtyp=41 if np>=9 & nrc==1
	replace hhpovtyp=42 if np>=9 & nrc==2
	replace hhpovtyp=43 if np>=9 & nrc==3
	replace hhpovtyp=44 if np>=9 & nrc==4
	replace hhpovtyp=45 if np>=9 & nrc==5
	replace hhpovtyp=46 if np>=9 & nrc==6
	replace hhpovtyp=47 if np>=9 & nrc==7
	replace hhpovtyp=48 if np>=9 & nrc>=8
	
	*merge poverty line
	merge m:1 hhpovtyp year using `povfile'
	tab _merge
	drop if _merge==2
	drop _merge
	
	*income relative to poverty line
	gen incpov=hincp/pov_ln

	*variable for mass point at 0
	gen obs=0

	*incpov spline
	gen incpov_50_100i=(incpov>0.5 & incpov<=1)
	gen incpov_100_150i=(incpov>1 & incpov<=1.5)
	gen incpov_150_200i=(incpov>1.5 & incpov<=2)
	gen incpov_g200i=(incpov>2)

	gen incpov_lt50s=incpov_lt50i*incpov
	gen incpov_50_100s=incpov_50_100i*incpov
	gen incpov_100_150s=incpov_100_150i*incpov
	gen incpov_150_200s=incpov_150_200i*incpov
	gen incpov_g200s=incpov_g200i*incpov

	*label variables
	label var pov_ln "HH poverty line"

	
	*keep required variables
	keep serialno wgtp obs fs ffs incpov_*i incpov_*s age18_29 age30_39 age50_59 age60_69 age_ge70 cap_inc np nc nm0kid nmwkid mar0kid noeng_hh n_emp any_emp eld_dis single_hh unempl nilf female non_cit rce_wht educ_lths educ_hs educ_cmor disab disnowrk badeng noeng pov_ln
	*save data
	compress
	save `outfile', replace
}

